* FROM: https://stats.idre.ucla.edu/sas/dae/ordinal-logistic-regression/;

* Generic session options - page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim=' ' spool;                                          
* Kill default titles on output, ODS tables in log, turn on graphics; 
TITLE; ODS TRACE OFF; ODS GRAPHICS ON;

********************************************************************************;
*******         BEGIN DATA MANIPULATION FOR EXAMPLE 2a and 2b            *******;
*******             CHANGE "filesave" to your folder path                *******;
********************************************************************************;

* Location for original files for these models  change this path;
* \\Client\ precedes path in Virtual Desktop outside H drive;
%LET filesave= C:\Dropbox\23_PSQF6270\PSQF6270_Example2ab; 
LIBNAME filesave "&filesave.";

/* Export data to STATA format;
PROC EXPORT DATA=filesave.SAS_Example2 OUTFILE="&filesave.\STATA_Example2.dta" 
     DBMS=STATA REPLACE; RUN; */

* Import data into work library, transform variables, apply labels;
DATA work.Example2; SET filesave.SAS_Example2;
* Create ID variable;
  PersonID=_N_;
* Rename 3-category outcome;
  apply3=apply;
* Create new binary outcome to demonstrate logistic regression;
  apply2=.; * New empty variable;
  IF apply3=0 THEN apply2=0;
  IF apply3>0 THEN apply2=1;
* Rename and center predictors;
  parD=pared; gpa3=gpa-3;
* Recode ref for public to create positive slope;
  priv=.;
  IF public=1 THEN priv=0; 
  IF public=0 THEN priv=1;
/* Label variables;
  LABEL apply3= "apply3: 0=Not, 1=Eh, 2=Very"
        apply2= "apply2: 0=No, 1=Pry"
        parD=   "parD: Parent Has Graduate Degree (0=N,1=Y)"
        priv=   "priv: Student Attends Private University (0=N,1=Y)"
        gpa3=   "gpa3: Student GPA (0=3)";  */
* Filter to only cases complete on all variables to be used below;
  IF NMISS(apply3, parD, priv, gpa3)>0 THEN DELETE;
RUN;

* Create fake people to generate predicted outcomes for;
DATA work.FakePeople; * Create new blank dataset;
* INPUT: list variables in order of entry;
  INPUT PersonID gpa3 parD priv; 
* Enter data -- each row is a fake person for which to create a predicted outcome;
  DATALINES; 
-99 -1 0 0
-99  0 0 0
-99  1 0 0
-99 -1 0 1
-99  0 0 1
-99  1 0 1
-99 -1 1 0
-99  0 1 0
-99  1 1 0
-99 -1 1 1
-99  0 1 1
-99  1 1 1
; RUN;
* Add fake people to real data;
DATA work.Example2; SET work.FakePeople work.Example2; RUN;


********************************************************************************;
******             BEGIN EXAMPLE 2a BINARY OUTCOME MODELS                *******;
********************************************************************************;

* Open external file to save results to for Example 2a;
ODS RTF FILE="&filesave.\PSQF6270_Example2a_SAS_Output.rtf" 
              BODYTITLE STYLE=HTMLBlue STARTPAGE=NO;

TITLE1 "SAS Descriptive Statistics";
PROC MEANS NDEC=2 DATA=work.Example2; 
     VAR gpa3 parD priv apply2; 
RUN;

*** NOTE: I am using SAS GLIMMIX because it has more helpful options 
*** (even though these are not mixed-effects models);

TITLE1 "SAS Empty Model Predicting Binary Apply2 using MSPL=ML";
PROC GLIMMIX DATA=work.Example2 NOCLPRINT GRADIENT METHOD=MSPL; 
* DESCENDING means predict prob=1 rather than prob=0;
  MODEL apply2 (DESCENDING) = / SOLUTION DDFM=NONE LINK=LOGIT DIST=BINARY;
* ILINK requests logit estimate to be transformed into probability;
  ESTIMATE "Intercept for y=1" int 1 / ILINK;
RUN; TITLE1; 


TITLE1 "SAS Main-Effects Model Predicting Binary Apply2";
PROC GLIMMIX DATA=work.Example2 NOCLPRINT GRADIENT METHOD=MSPL;
MODEL apply2 (DESCENDING) = gpa3 parD priv 
      / SOLUTION DDFM=NONE LINK=LOGIT DIST=BINARY ODDSRATIO(AT gpa3=0 LABEL);
* Get predicted outcomes (duplicates estimates below with less effort);
OUTPUT OUT=work.Pred2Main PRED(NOILINK)=Ylogit STDERR(NOILINK)=YlogitSE
                          PRED(ILINK)=Yprob    STDERR(ILINK)=YprobSE;
* Predicted outcomes in logits and ILINK=probability;
ESTIMATE "Yhat: Ndeg Pub GPA=2"  int 1 gpa3 -1 parD 0 priv 0 / ILINK;
ESTIMATE "Yhat: Ndeg Pub GPA=3"  int 1 gpa3  0 parD 0 priv 0 / ILINK;
ESTIMATE "Yhat: Ndeg Pub GPA=4"  int 1 gpa3  1 parD 0 priv 0 / ILINK;
ESTIMATE "Yhat: Ndeg Pri GPA=2"  int 1 gpa3 -1 parD 0 priv 1 / ILINK;
ESTIMATE "Yhat: Ndeg Pri GPA=3"  int 1 gpa3  0 parD 0 priv 1 / ILINK;
ESTIMATE "Yhat: Ndeg Pri GPA=4"  int 1 gpa3  1 parD 0 priv 1 / ILINK;
ESTIMATE "Yhat: Ydeg Pub GPA=2"  int 1 gpa3 -1 parD 1 priv 0 / ILINK;
ESTIMATE "Yhat: Ydeg Pub GPA=3"  int 1 gpa3  0 parD 1 priv 0 / ILINK;
ESTIMATE "Yhat: Ydeg Pub GPA=4"  int 1 gpa3  1 parD 1 priv 0 / ILINK;
ESTIMATE "Yhat: Ydeg Pri GPA=2"  int 1 gpa3 -1 parD 1 priv 1 / ILINK;
ESTIMATE "Yhat: Ydeg Pri GPA=3"  int 1 gpa3  0 parD 1 priv 1 / ILINK;
ESTIMATE "Yhat: Ydeg Pri GPA=4"  int 1 gpa3  1 parD 1 priv 1 / ILINK;
ESTIMATE "GPA Slope" gpa3 1 / ILINK; * Example of non-sense ILINK for a slope; 
RUN; 
TITLE1 "Predicted Logits and Probabilities for Fake People";
PROC PRINT NOOBS DATA=work.Pred2Main; WHERE PersonID=-99;
     VAR gpa3 parD priv Ylogit--YprobSE;
RUN; TITLE1; 


TITLE1 "SAS Interaction Model Predicting Binary Apply2";
PROC GLIMMIX DATA=work.Example2 NOCLPRINT GRADIENT METHOD=MSPL;  
MODEL apply2 (DESCENDING) = gpa3 parD priv gpa3*parD gpa3*priv
      / SOLUTION DDFM=NONE LINK=LOGIT DIST=BINARY ODDSRATIO(AT gpa3=0 DIFF=ALL LABEL);
* Get predicted outcomes (duplicates estimates below with less effort;
OUTPUT OUT=work.Pred2Int PRED(NOILINK)=Ylogit STDERR(NOILINK)=YlogitSE
                         PRED(ILINK)=Yprob    STDERR(ILINK)=YprobSE;
* Predicted outcomes in logits and ILINK=probability;
ESTIMATE "Yhat: Ndeg Pub GPA=2"  int 1 gpa3 -1 parD 0 priv 0 gpa3*parD  0 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ndeg Pub GPA=3"  int 1 gpa3  0 parD 0 priv 0 gpa3*parD  0 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ndeg Pub GPA=4"  int 1 gpa3  1 parD 0 priv 0 gpa3*parD  0 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ndeg Pri GPA=2"  int 1 gpa3 -1 parD 0 priv 1 gpa3*parD  0 gpa3*priv -1 / ILINK;
ESTIMATE "Yhat: Ndeg Pri GPA=3"  int 1 gpa3  0 parD 0 priv 1 gpa3*parD  0 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ndeg Pri GPA=4"  int 1 gpa3  1 parD 0 priv 1 gpa3*parD  0 gpa3*priv  1 / ILINK;
ESTIMATE "Yhat: Ydeg Pub GPA=2"  int 1 gpa3 -1 parD 1 priv 0 gpa3*parD -1 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ydeg Pub GPA=3"  int 1 gpa3  0 parD 1 priv 0 gpa3*parD  0 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ydeg Pub GPA=4"  int 1 gpa3  1 parD 1 priv 0 gpa3*parD  1 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ydeg Pri GPA=2"  int 1 gpa3 -1 parD 1 priv 1 gpa3*parD -1 gpa3*priv -1 / ILINK;
ESTIMATE "Yhat: Ydeg Pri GPA=3"  int 1 gpa3  0 parD 1 priv 1 gpa3*parD  0 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ydeg Pri GPA=4"  int 1 gpa3  1 parD 1 priv 1 gpa3*parD  1 gpa3*priv  1 / ILINK;
* Simple slopes for GPA by moderators (EXP to get odds ratios, add CL for CIs);
ESTIMATE "GPA Slope: Ndeg Pub"  gpa3 1 gpa3*parD 0 gpa3*priv 0 / EXP;
ESTIMATE "GPA Slope: Ndeg Pri"  gpa3 1 gpa3*parD 0 gpa3*priv 1 / EXP;
ESTIMATE "GPA Slope: Ydeg Pub"  gpa3 1 gpa3*parD 1 gpa3*priv 0 / EXP;
ESTIMATE "GPA Slope: Ydeg Pri"  gpa3 1 gpa3*parD 1 gpa3*priv 1 / EXP;
RUN; 
TITLE1 "Predicted Logits and Probabilities for Fake People";
PROC PRINT NOOBS DATA=work.Pred2Int; WHERE PersonID=-99;
     VAR gpa3 parD priv Ylogit--YprobSE;
RUN; TITLE1; 


TITLE1 "SAS Interaction Model Predicting Binary Apply2";
TITLE2 "Using Probit Link Instead of Logit Link";
PROC GLIMMIX DATA=work.Example2 NOCLPRINT GRADIENT METHOD=MSPL;
MODEL apply2 (DESCENDING) = gpa3 parD priv gpa3*parD gpa3*priv
       / SOLUTION DDFM=NONE LINK=PROBIT DIST=BINARY ODDSRATIO(AT gpa3=0 LABEL);
* Get predicted outcomes (duplicates estimates below with less effort);
OUTPUT OUT=work.Pred2IntProbit PRED(NOILINK)=Yprobit STDERR(NOILINK)=YprobitSE
                               PRED(ILINK)=Yprob     STDERR(ILINK)=YprobSE;
* Predicted outcomes in PROBITS and ILINK=probability;
ESTIMATE "Yhat: Ndeg Pub GPA=2"  int 1 gpa3 -1 parD 0 priv 0 gpa3*parD  0 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ndeg Pub GPA=3"  int 1 gpa3  0 parD 0 priv 0 gpa3*parD  0 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ndeg Pub GPA=4"  int 1 gpa3  1 parD 0 priv 0 gpa3*parD  0 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ndeg Pri GPA=2"  int 1 gpa3 -1 parD 0 priv 1 gpa3*parD  0 gpa3*priv -1 / ILINK;
ESTIMATE "Yhat: Ndeg Pri GPA=3"  int 1 gpa3  0 parD 0 priv 1 gpa3*parD  0 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ndeg Pri GPA=4"  int 1 gpa3  1 parD 0 priv 1 gpa3*parD  0 gpa3*priv  1 / ILINK;
ESTIMATE "Yhat: Ydeg Pub GPA=2"  int 1 gpa3 -1 parD 1 priv 0 gpa3*parD -1 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ydeg Pub GPA=3"  int 1 gpa3  0 parD 1 priv 0 gpa3*parD  0 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ydeg Pub GPA=4"  int 1 gpa3  1 parD 1 priv 0 gpa3*parD  1 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ydeg Pri GPA=2"  int 1 gpa3 -1 parD 1 priv 1 gpa3*parD -1 gpa3*priv -1 / ILINK;
ESTIMATE "Yhat: Ydeg Pri GPA=3"  int 1 gpa3  0 parD 1 priv 1 gpa3*parD  0 gpa3*priv  0 / ILINK;
ESTIMATE "Yhat: Ydeg Pri GPA=4"  int 1 gpa3  1 parD 1 priv 1 gpa3*parD  1 gpa3*priv  1 / ILINK;
* Simple slopes for GPA by moderators (add CL for CIs);
ESTIMATE "GPA Slope: Ndeg Pub"  gpa3 1 gpa3*parD 0 gpa3*priv 0 / CL;
ESTIMATE "GPA Slope: Ndeg Pri"  gpa3 1 gpa3*parD 0 gpa3*priv 1 / CL;
ESTIMATE "GPA Slope: Ydeg Pub"  gpa3 1 gpa3*parD 1 gpa3*priv 0 / CL;
ESTIMATE "GPA Slope: Ydeg Pri"  gpa3 1 gpa3*parD 1 gpa3*priv 1 / CL;
RUN; TITLE2;
TITLE1 "Predicted Probits and Probabilities for Fake People";
PROC PRINT NOOBS DATA=work.Pred2IntProbit; WHERE PersonID=-99;
     VAR gpa3 parD priv Yprobit--YprobSE;
RUN; TITLE1; 

* Close external output file of saved results for Example 2a;
ODS RTF CLOSE; 


********************************************************************************;
******             BEGIN EXAMPLE 2b CATEGORICAL OUTCOME MODELS           *******;
********************************************************************************;

* Open external file to save results to for Example 2b;
ODS RTF FILE="&filesave.\PSQF6270_Example2b_SAS_Output.rtf" 
              BODYTITLE STYLE=HTMLBlue STARTPAGE=NO;

TITLE1 "SAS Descriptive Statistics";
PROC FREQ DATA=work.Example2;
     TABLE apply3;
RUN; TITLE1;

**************************** BEGIN ORDINAL MODELS ***************************;

TITLE1 "SAS Empty Model Predicting Ordinal Apply3 using MSPL=ML";
PROC GLIMMIX DATA=work.Example2 NOCLPRINT GRADIENT METHOD=MSPL; 
MODEL apply3 (DESCENDING) = / SOLUTION DDFM=NONE LINK=CLOGIT DIST=MULT;
ESTIMATE "Intercept for y>1 (=2)"   int 1 0  / ILINK; * Highest is first;
ESTIMATE "Intercept for y>0 (=1+2)" int 0 1  / ILINK;
RUN; TITLE1; 

TITLE1 "SAS Proportional Odds Model Predicting Ordinal Apply3";
PROC GLIMMIX DATA=work.Example2 NOCLPRINT GRADIENT METHOD=QUAD; 
MODEL apply3 (DESCENDING) = gpa3 parD priv 
      / SOLUTION DDFM=NONE LINK=CLOGIT DIST=MULT ODDSRATIO(AT gpa3=0 LABEL);
* Fake people will not work to get predicted outcomes;
ESTIMATE "y>1 Yhat: Ndeg Pub GPA=2"  int 1 0 gpa3 -1 parD 0 priv 0 / ILINK;
ESTIMATE "y>1 Yhat: Ndeg Pub GPA=3"  int 1 0 gpa3  0 parD 0 priv 0 / ILINK;
ESTIMATE "y>1 Yhat: Ndeg Pub GPA=4"  int 1 0 gpa3  1 parD 0 priv 0 / ILINK;
ESTIMATE "y>1 Yhat: Ndeg Pri GPA=2"  int 1 0 gpa3 -1 parD 0 priv 1 / ILINK;
ESTIMATE "y>1 Yhat: Ndeg Pri GPA=3"  int 1 0 gpa3  0 parD 0 priv 1 / ILINK;
ESTIMATE "y>1 Yhat: Ndeg Pri GPA=4"  int 1 0 gpa3  1 parD 0 priv 1 / ILINK;
ESTIMATE "y>1 Yhat: Ydeg Pub GPA=2"  int 1 0 gpa3 -1 parD 1 priv 0 / ILINK;
ESTIMATE "y>1 Yhat: Ydeg Pub GPA=3"  int 1 0 gpa3  0 parD 1 priv 0 / ILINK;
ESTIMATE "y>1 Yhat: Ydeg Pub GPA=4"  int 1 0 gpa3  1 parD 1 priv 0 / ILINK;
ESTIMATE "y>1 Yhat: Ydeg Pri GPA=2"  int 1 0 gpa3 -1 parD 1 priv 1 / ILINK;
ESTIMATE "y>1 Yhat: Ydeg Pri GPA=3"  int 1 0 gpa3  0 parD 1 priv 1 / ILINK;
ESTIMATE "y>1 Yhat: Ydeg Pri GPA=4"  int 1 0 gpa3  1 parD 1 priv 1 / ILINK;
ESTIMATE "y>0 Yhat: Ndeg Pub GPA=2"  int 0 1 gpa3 -1 parD 0 priv 0 / ILINK;
ESTIMATE "y>0 Yhat: Ndeg Pub GPA=3"  int 0 1 gpa3  0 parD 0 priv 0 / ILINK;
ESTIMATE "y>0 Yhat: Ndeg Pub GPA=4"  int 0 1 gpa3  1 parD 0 priv 0 / ILINK;
ESTIMATE "y>0 Yhat: Ndeg Pri GPA=2"  int 0 1 gpa3 -1 parD 0 priv 1 / ILINK;
ESTIMATE "y>0 Yhat: Ndeg Pri GPA=3"  int 0 1 gpa3  0 parD 0 priv 1 / ILINK;
ESTIMATE "y>0 Yhat: Ndeg Pri GPA=4"  int 0 1 gpa3  1 parD 0 priv 1 / ILINK;
ESTIMATE "y>0 Yhat: Ydeg Pub GPA=2"  int 0 1 gpa3 -1 parD 1 priv 0 / ILINK;
ESTIMATE "y>0 Yhat: Ydeg Pub GPA=3"  int 0 1 gpa3  0 parD 1 priv 0 / ILINK;
ESTIMATE "y>0 Yhat: Ydeg Pub GPA=4"  int 0 1 gpa3  1 parD 1 priv 0 / ILINK;
ESTIMATE "y>0 Yhat: Ydeg Pri GPA=2"  int 0 1 gpa3 -1 parD 1 priv 1 / ILINK;
ESTIMATE "y>0 Yhat: Ydeg Pri GPA=3"  int 0 1 gpa3  0 parD 1 priv 1 / ILINK;
ESTIMATE "y>0 Yhat: Ydeg Pri GPA=4"  int 0 1 gpa3  1 parD 1 priv 1 / ILINK;
ESTIMATE "GPA Slope" gpa3 1 / ILINK; * Example of non-sense ILINK for a slope; 
ODS OUTPUT Estimates=work.Pred3PO;   * Save estimates table as dataset to do math;
RUN; 
* Convert predicted logits into probabilities;
DATA work.Pred3PO_y2; SET work.Pred3PO; WHERE INDEX(Label,"y>1")>0;
     RENAME Estimate=Logit2 Mu=Prob2; KEEP Label Estimate Mu; RUN;
DATA work.Pred3PO_y1; SET work.Pred3PO; WHERE INDEX(Label,"y>0")>0;
     RENAME Estimate=Logit12 Mu=Prob12; KEEP Label Estimate Mu; RUN;
DATA work.Pred2PO_Prob; MERGE work.Pred3PO_y2 work.Pred3PO_y1;
     Prob0=1-Prob12; Prob1=Prob12-Prob2; 
     Label=SUBSTR(Label,11); RUN;
TITLE1 "Predicted Logits and Probabilities for Fake People";
PROC PRINT NOOBS DATA=work.Pred2PO_Prob;
     VAR Label Logit12 Logit2 Prob0 Prob1 Prob2; 
RUN; TITLE1;


TITLE1 "SAS Ordinal Model Testing Proportional Odds for Apply3";
TITLE2 "Must Use LOGISTIC Instead of GLIMMIX";
PROC LOGISTIC DATA=work.Example2; 
MODEL apply3 (DESCENDING) = gpa3 parD priv / LINK=CLOGIT UNEQUALSLOPES;
* Univ Wald tests of submodel slope differences;
gpa3_SlopePO: TEST gpa3_2=gpa3_1;
parD_SlopePO: TEST parD_2=parD_1;
priv_SlopePO: TEST priv_2=priv_1;
RUN;

TITLE1 "SAS Automated Non-Proportional Odds Model Predicting Ordinal Apply3";
PROC LOGISTIC DATA=work.Example2; 
MODEL apply3 (DESCENDING) = gpa3 parD priv / LINK=CLOGIT 
/* Start with unequal slopes and remove if p>.05, keep 3 slopes minimum */
   EQUALSLOPES UNEQUALSLOPES SELECTION=BACKWARD STOP=3 DETAILS;
RUN;

TITLE1 "SAS Partial Proportional Odds Model Predicting Ordinal Apply3";
PROC LOGISTIC DATA=work.Example2; 
MODEL apply3 (DESCENDING) = gpa3 parD priv / LINK=CLOGIT UNEQUALSLOPES=priv;
priv_SlopePO: TEST priv_2=priv_1; * Test submodel slope difference;
RUN;

* MY TESTS TO MAKE SURE I UNDERSTOOD WHAT EACH PROGRAM DOES;
TITLE1 "SAS Main-Effects Ordinal Model Testing Proportional Odds";
TITLE2 "Using NLMIXED to Estimate a Custom Model";
PROC NLMIXED DATA=work.Example2 METHOD=GAUSS TECH=QUANEW GCONV=1e-12;
* Must list all parms to be estimated here with start values;
* B00 and B01 = intercepts for each equation;
* Bs = fixed effects, now separate per equation;
PARMS B01=-2.5 B11gpa3=0 B21parD=0 B31priv=0 
      B00=-0.4 B10gpa3=0 B20parD=0 B30priv=0;
* Linear predictor for y>1 and y>0;
Y1 = B01 + B11gpa3*gpa3 + B21parD*parD + B31priv*priv;
Y0 = B00 + B10gpa3*gpa3 + B20parD*parD + B30priv*priv;
* Model for probability of response - writing it the shorter way;
     IF (apply3=0) THEN P = 1 - (1/(1 + EXP(-Y0)));
ELSE IF (apply3=1) THEN P =     (1/(1 + EXP(-Y0))) - (1/(1 + EXP(-Y1)));
ELSE IF (apply3=2) THEN P =                          (1/(1 + EXP(-Y1)));
* Define log-likelihood using response probabilities;
LL = LOG(P); MODEL apply3 ~ GENERAL(LL);
* Testing proportional odds;
ESTIMATE "GPA3 Slope Diff"  B11gpa3 - B10gpa3;
ESTIMATE "ParD Slope Diff"  B21parD - B20parD;
ESTIMATE "Priv Slope Diff"  B31priv - B30priv;
RUN;


************************** BEGIN NOMINAL MODELS ******************************;

TITLE1 "SAS Empty Model Predicting Nominal Apply3 using MSPL=ML";
PROC GLIMMIX DATA=work.Example2 NOCLPRINT GRADIENT METHOD=MSPL; 
MODEL apply3 (REFERENCE="1") = / SOLUTION DDFM=NONE LINK=GLOGIT DIST=MULT;
* ILINK requests logit estimate to be transformed into probability;
  ESTIMATE "Intercept" int 1 / ILINK BYCAT; * BYCAT gives per submodel;
RUN; TITLE1; 

TITLE1 "SAS Main-Effects Nominal Model";
PROC GLIMMIX DATA=work.Example2 NOCLPRINT GRADIENT METHOD=MSPL; 
MODEL apply3 (REFERENCE="1") = gpa3 parD priv 
      / SOLUTION DDFM=NONE LINK=GLOGIT DIST=MULT ODDSRATIO(AT gpa3=0 LABEL);
CONTRAST "Multiv Wald Test of Model R2"  gpa3 1, parD 1, priv 1 / CHISQ;
ESTIMATE "Yhat: Ndeg, Pub, GPA=2" int 1 gpa3 -1 parD 0 priv 0 / ILINK BYCAT;
ESTIMATE "Yhat: Ndeg, Pub, GPA=3" int 1 gpa3  0 parD 0 priv 0 / ILINK BYCAT;
ESTIMATE "Yhat: Ndeg, Pub, GPA=4" int 1 gpa3  1 parD 0 priv 0 / ILINK BYCAT;
ESTIMATE "Yhat: Ndeg, Pri, GPA=2" int 1 gpa3 -1 parD 0 priv 1 / ILINK BYCAT;
ESTIMATE "Yhat: Ndeg, Pri, GPA=3" int 1 gpa3  0 parD 0 priv 1 / ILINK BYCAT;
ESTIMATE "Yhat: Ndeg, Pri, GPA=4" int 1 gpa3  1 parD 0 priv 1 / ILINK BYCAT;
ESTIMATE "Yhat: Ydeg, Pub, GPA=2" int 1 gpa3 -1 parD 1 priv 0 / ILINK BYCAT;
ESTIMATE "Yhat: Ydeg, Pub, GPA=3" int 1 gpa3  0 parD 1 priv 0 / ILINK BYCAT;
ESTIMATE "Yhat: Ydeg, Pub, GPA=4" int 1 gpa3  1 parD 1 priv 0 / ILINK BYCAT;
ESTIMATE "Yhat: Ydeg, Pri, GPA=2" int 1 gpa3 -1 parD 1 priv 1 / ILINK BYCAT;
ESTIMATE "Yhat: Ydeg, Pri, GPA=3" int 1 gpa3  0 parD 1 priv 1 / ILINK BYCAT;
ESTIMATE "Yhat: Ydeg, Pri, GPA=4" int 1 gpa3  1 parD 1 priv 1 / ILINK BYCAT;
RUN; TITLE1; 


* Close external file of saved results for Example 2b;
ODS RTF CLOSE; 

