// Prevent "more" messages from appearing
set more off
// Control line length
set linesize 150

///////////////////////////////////////////////////////////////////////////////////////
////////               BEGIN DATA MANIPULATION FOR EXAMPLE 2a and 2b            ///////
////////                  CHANGE "filesave" TO YOUR FOLDER PATH                 ///////
///////////////////////////////////////////////////////////////////////////////////////

// Defining global variable for file location to be replaced in code below
// \\Client\ precedes path in Virtual Desktop outside H drive
global filesave "C:\Dropbox\23_PSQF6270\PSQF6270_Example2ab"

// Open Example 2 STATA dataset and clear away any existing data
use "$filesave\STATA_Example2.dta", clear // Has converted all variables to lower-case

// Create ID variable
gen PersonID = _n
// Rename 3-category outcome
gen apply3=apply
// Create new binary outcome to demonstrate logistic regression 
gen apply2=.  // New empty variable
replace apply2=0 if apply==0
replace apply2=1 if apply>0
// Rename and center predictors
gen parD=pared
gen gpa3=gpa-3
// Recode ref for public to create positive slope
gen priv=.
replace priv=0 if public==1 
replace priv=1 if public==0
// Label variables 
label variable apply3 "apply3: 0=Not, 1=Eh, 2=Very"
label variable apply2 "apply2: 0=No, 1=Pry"
label variable parD   "parD: Parent Has Graduate Degree (0=N,1=Y)"
label variable priv   "priv: Student Attends Private University (0=N,1=Y)"
label variable gpa3   "gpa3: Student GPA (0=3)"


// Need to find and install a new package -- first run this:
search fitstat
// Scroll to "packages"
// Then in new window select "click here to install" 
// Then can use fitstat below

///////////////////////////////////////////////////////////////////////////////////////
////////                BEGIN EXAMPLE 2a BINARY OUTCOME MODELS                 ////////
///////////////////////////////////////////////////////////////////////////////////////

// Open external file to save results to
log using $filesave\PSQF6270_Example2a_STATA_Output.log, replace name(Example2a)
 
display "STATA Descriptive Statistics"
summarize gpa3 parD priv apply2

display "STATA Empty Model Predicting Binary Apply2"
logit apply2, nolog  
display "-2LL= " e(ll)*-2  // Print -2LL for model
estat ic, n(400)           // AIC and BIC using N=400
margins                    // Intercept in probability

///////////////////////////////////////////////////////////////////////////////////////
display "STATA Main-Effects Model Predicting Binary Apply2"
logit apply2 c.gpa3 c.parD c.priv, nolog
estimates store Main       // Save for next LRT 
display "-2LL= " e(ll)*-2  // Print -2LL for model
estat ic, n(400)           // AIC and BIC using N=400
fitstat                    // Additional R2 and fit stats (user-defined function)
// For at, (from(by)to) for range of predictors
margins, at(c.gpa3=(-1(1)1) c.parD=0 c.priv=0) predict(xb) // Example yhat in logits
margins, at(c.gpa3=(-1(1)1) c.parD=0 c.priv=0)             // Example yhat in probability 

// Must re-estimate with 'or' added to first line to get odds ratios
display "STATA Main-Effects-Only Model Predicting Binary Apply2"
display "Get Odds Ratios Instead of Logit Fixed Effects"
logit apply2 c.gpa3 c.parD c.priv, or

///////////////////////////////////////////////////////////////////////////////////////     
display "STATA Interaction Model Predicting Binary Apply2"
logit apply2 c.gpa3 c.parD c.priv c.gpa3#c.parD c.gpa3#c.priv, nolog
estimates store Interact   // Save for this LRT 
display "-2LL= " e(ll)*-2  // Print -2LL for model
estat ic, n(400)           // AIC and BIC using N=400
lrtest Interact Main       // LRT for 2 new interaction terms ("fewer" model goes LAST)
// For at, (from(by)to) for range of predictors
margins, at(c.gpa3=(-1(1)1) c.parD=(0(1)1) c.priv=(0(1)1)) predict(xb) // Yhat in logits
margins, at(c.gpa3=(-1(1)1) c.parD=(0(1)1) c.priv=(0(1)1))             // Yhat in probability 
lincom c.gpa3*1 + c.gpa3#c.parD*0 + c.gpa3#c.priv*0  // GPA slope: Ndeg Pub = B1
lincom c.gpa3*1 + c.gpa3#c.parD*0 + c.gpa3#c.priv*1  // GPA slope: Ndeg Pri = B1+B5 
lincom c.gpa3*1 + c.gpa3#c.parD*1 + c.gpa3#c.priv*0  // GPA slope: Ydeg Pub = B1+B4
lincom c.gpa3*1 + c.gpa3#c.parD*1 + c.gpa3#c.priv*1  // GPA slope: Ydeg Pri = B1+B4+B5
  
// Must re-estimate with 'or' added to first line to get odds ratios
display "STATA Interaction Model Predicting Binary Apply2"
display "Get Odds Ratios Instead of Logit Fixed Effects"
logit apply2 c.gpa3 c.parD c.priv c.gpa3#c.parD c.gpa3#c.priv, or nolog
lincom c.gpa3*1 + c.gpa3#c.parD*0 + c.gpa3#c.priv*0, or  // GPA slope: Ndeg Pub = B1
lincom c.gpa3*1 + c.gpa3#c.parD*0 + c.gpa3#c.priv*1, or  // GPA slope: Ndeg Pri = B1+B5 
lincom c.gpa3*1 + c.gpa3#c.parD*1 + c.gpa3#c.priv*0, or  // GPA slope: Ydeg Pub = B1+B4
lincom c.gpa3*1 + c.gpa3#c.parD*1 + c.gpa3#c.priv*1, or  // GPA slope: Ydeg Pri = B1+B4+B5

display "STATA Interaction Model Predicting Binary Apply2"
display "Using Probit Instead of Logit"
probit apply2 c.gpa3 c.parD c.priv c.gpa3#c.parD c.gpa3#c.priv, nolog
display "-2LL= " e(ll)*-2  // Print -2LL for model
estat ic, n(400)           // AIC and BIC using N=400
// For at, (from(by)to) for range of predictors
margins, at(c.gpa3=(-1(1)1) c.parD=(0(1)1) c.priv=(0(1)1)) predict(xb) // Yhat in probits
margins, at(c.gpa3=(-1(1)1) c.parD=(0(1)1) c.priv=(0(1)1))             // Yhat in probability 
lincom c.gpa3*1 + c.gpa3#c.parD*0 + c.gpa3#c.priv*0  // GPA slope: Ndeg Pub = B1
lincom c.gpa3*1 + c.gpa3#c.parD*0 + c.gpa3#c.priv*1  // GPA slope: Ndeg Pri = B1+B5 
lincom c.gpa3*1 + c.gpa3#c.parD*1 + c.gpa3#c.priv*0  // GPA slope: Ydeg Pub = B1+B4
lincom c.gpa3*1 + c.gpa3#c.parD*1 + c.gpa3#c.priv*1  // GPA slope: Ydeg Pri = B1+B4+B5

     
// Close external file of saved results    
log close Example2a


///////////////////////////////////////////////////////////////////////////////////////
////////                BEGIN EXAMPLE 2b CATEGORICAL OUTCOME MODELS            ////////
///////////////////////////////////////////////////////////////////////////////////////

// Open external file to save results to
log using $filesave\PSQF6270_Example2b_STATA_Output.log, replace name(Example2b)
 
display "STATA Descriptive Statistics"
summarize gpa3 parD priv 
tabulate apply3 
 
// Need to find and install a new package -- first run this:
search gologit2
// Now click on third link "Software update for gologit2"
// Then in new window select "click here to install" 
// Then can use gologit2 below

//////////////////////////// BEGIN EMPTY ORDINAL MODELS ///////////////////////////////

display "STATA Empty Model Predicting Ordinal Apply3 Using GOLOGIT2"
display "GOLOGIT2 Gives Intercepts (Logit of Higher Category), not Thresholds"  
gologit2 apply3, nolog   
display "-2LL= " e(ll)*-2  // Print -2LL for model
estat ic, n(400)           // AIC and BIC using N=400
margins                    // All 3 probabilities
// If above margins does not work, try it this way
//margins, predict(outcome(0)) predict(outcome(1)) predict(outcome(2)) // All 3 probabilities

display "STATA Empty Model Predicting Ordinal Apply3 Using OLOGIT Instead"
display "OLOGIT Gives Thresholds (Logit of Lower Category), not Intercepts" 
ologit apply3, nolog
display "-2LL= " e(ll)*-2  // Print -2LL for model
estat ic, n(400)           // AIC and BIC using N=400
margins                    // All 3 probabilities

/////////////////// BEGIN PROPORTIONAL ODDS ORDINAL MODELS ////////////////////////////

display "STATA Proportional Odds Model Predicting Ordinal Apply3"
// If you get an error with the code below, remove the c. from each predictor
gologit2 apply3 c.gpa3 c.parD c.priv, pl nolog 
display "-2LL= " e(ll)*-2  // Print -2LL for model
estat ic, n(400)           // AIC and BIC using N=400
estimates store PO         // Save for LRT
           
display "STATA Proportional Odds Model Predicting Ordinal Apply3"
display "Get Odds Ratios Instead of Logit Fixed Effects"
gologit2 apply3 c.gpa3 c.parD c.priv, pl or

//////////////// BEGIN NON/PARTIAL PROPORTIONAL ODDS ORDDINAL MODELS /////////////////

display "STATA Non-Proportional Odds Model Predicting Ordinal Apply3"
display "Directly provides each slope and differences in slopes across submodels"
gologit2 apply3 c.gpa3 c.parD c.priv, gamma nolog
display "-2LL= " e(ll)*-2  // Print -2LL for model
estat ic, n(400)           // AIC and BIC using N=400
estimates store NPO        // Save for LRT
lrtest NPO PO              // LRT for overall proportional odds ("fewer" model goes LAST)

display "STATA Automated Non-Proportional Odds Model Predicting Ordinal Apply3"
gologit2 apply3 c.gpa3 c.parD c.priv, gamma auto nolog
display "-2LL= " e(ll)*-2  // Print -2LL for model
estat ic, n(400)           // AIC and BIC using N=400

display "STATA Partial Proportional Odds Model Predicting Ordinal Apply3"
gologit2 apply3 c.gpa3 c.parD c.priv, npl(c.priv) gamma nolog
display "-2LL= " e(ll)*-2  // Print -2LL for model
estat ic, n(400)           // AIC and BIC using N=400
margins, at(c.gpa3=(-1(1)1) c.parD=(0(1)1) c.priv=(0(1)1)) predict(xb) // Yhat>0 in logits
margins, at(c.gpa3=(-1(1)1) c.parD=(0(1)1) c.priv=(0(1)1))     // Each Yhat in probability 
// If above margins does not work, try it this way
//margins, at(c.gpa3=(-1(1)1) c.parD=(0(1)1) c.priv=(0(1)1))  /// Each Yhat in probability         
//           predict(outcome(0)) predict(outcome(1)) predict(outcome(2)) 

display "STATA Partial Proportional Odds Model Predicting Ordinal Apply3"
display "Get Odds Ratios Instead of Logit Fixed Effects"
gologit2 apply3 c.gpa3 c.parD c.priv, npl(c.priv) gamma or nolog


////////////////////////////////// BEGIN NOMINAL MODELS ///////////////////////////////
     
display "STATA Empty Model Predicting Nominal Apply3 -- ref is SECOND category of y=1"
mlogit apply3, baseoutcome(1) nolog 
display "-2LL= " e(ll)*-2  // Print -2LL for model
estat ic, n(400)           // AIC and BIC using N=400
margins                    // All 3 probabilities
     
display "STATA 3-Predictor Model Predicting Nominal Apply3 -- ref is SECOND category of y=1"
mlogit apply3 c.gpa3 c.parD c.priv, baseoutcome(1) nolog
display "-2LL= " e(ll)*-2  // Print -2LL for model
estat ic, n(400)           // AIC and BIC using N=400
// Univ Wald tests of submodel slope diffs after reversing sign of [0]
lincom [0]c.gpa3*1 + [2]c.gpa3*1  // gpa3 slope diff
lincom [0]c.parD*1 + [2]c.parD*1  // parD slope diff
lincom [0]c.priv*1 + [2]c.priv*1  // priv slope diff
margins, at(c.gpa3=(-1(1)1) c.parD=(0(1)1) c.priv=(0(1)1)) predict(xb) // Yhat logits for 1 vs 0
margins, at(c.gpa3=(-1(1)1) c.parD=(0(1)1) c.priv=(0(1)1))             // All 3 probabilities  
     
display "STATA 3-Predictor Model Predicting Nominal Apply3 -- ref is SECOND category of y=1"
display "Get Odds (Relative Risk) Ratios Instead of Logit Fixed Effects"
mlogit apply3 c.gpa3 c.parD c.priv, baseoutcome(1) rrr nolog
  
     
// Close external file of saved results    
log close Example2b
